```@meta
CurrentModule = Persefone
```

# Introduction

Persefone is an agent-based, socio-economic-ecological model of agricultural landscapes
in Europe under the Common Agricultural Policy (CAP).

It's aim is to investigate how policy affects farmer decision-making, and how this in turn
affects various animal species. It includes a farm submodel, a crop-growth submodel, and
an ecological submodels.

## Running the model

To run a single experiment, execute `run.jl`:

```
julia run.jl -c <CONFIG>
```

Other commandline arguments are:

```
usage: run.jl [-c CONFIGFILE] [-s SEED] [-o OUTDIR] [-l LOGLEVEL] 
              [--version] [-h]

optional arguments:
  -c, --configfile CONFIGFILE
                        name of the configuration file
  -s, --seed SEED       inital random seed (type: Int64)
  -o, --outdir OUTDIR   location of the output directory
  -l, --loglevel LOGLEVEL
                        verbosity: "debug", "info", or "quiet"
  --version             show version information and exit
  -h, --help            show this help message and exit
```

## Model input

Persefone requires three input files: a configuration file and two map files. How to generate
the map files is documented [elsewhere](gis.html). The [configuration file](io.html)
defines parameter values and looks like this (see `src/parameters.toml` for a complete list 
of parameters):

```TOML
### Persefone - a socio-economic-ecological model of European agricultural landscapes.
###
### This is the default configuration file for Persefone, containing all model parameters.
### The syntax is described here: https://toml.io/en/

[core]
configfile = "src/parameters.toml" # location of the configuration file
outdir = "results" # location and name of the output folder
overwrite = "ask" # overwrite the output directory? (true/false/"ask")
loglevel = "debug" # verbosity level: "debug", "info", "warn"
processors = 2 # number of processors to use on parallel runs
seed = 2 # seed value for the RNG (0 -> random value)
# dates to start and end the simulation
startdate = 2022-01-01
enddate = 2022-12-31

[world]
landcovermap = "data/landcover_jena.tif" # location of the landcover map
farmfieldsmap = "data/fields_jena.tif" # location of the field geometry map

[farm]
farmmodel = "FieldManager" # which version of the farm model to use (not yet implemented)

[nature]
targetspecies = ["Wolpertinger", "Wyvern"] # list of target species to simulate
popoutfreq = "daily" # output frequency population-level data, daily/monthly/yearly/end/never
indoutfreq = "end" # output frequency individual-level data, daily/monthly/yearly/end/never
	
[crop]
cropmodel = "linear" # crop growth model to use, "linear" or "aquacrop" (not yet implemented)
```

!!! info "Parameter scanning"
	You can set any parameter to a list of different values, e.g. `seed = [1,2,3]`.
	Persefone will then set up and run multiple simulations, one for every possible
	combination of parameters that you entered (i.e. do a full-factorial simulation
	experiment).

*Last updated: 2023-07-27 (commit 1e6e7d6)*
